==> pointpos_api-0.0.16.tar.gz: test/sales_type_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for SalesTypeApi
void main() {
  var instance = new SalesTypeApi();

  group('tests for SalesTypeApi', () {
    // Create Salestype
    //
    // Create Salestype
    //
    //Future<SalesType> createSalestype(String authorization, String xAPIKey, SalesType body, { String xPin }) async 
    test('test createSalestype', () async {
      // TODO
    });

    // Delete Salestype By ID
    //
    // Delete Salestype By ID
    //
    //Future deleteSalestypeByID(String authorization, String xAPIKey, String name, { String xPin }) async 
    test('test deleteSalestypeByID', () async {
      // TODO
    });

    // Get Salestype List
    //
    // Get Salestype  List
    //
    //Future<List<SalesType>> findSalestype(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findSalestype', () async {
      // TODO
    });

    // Get Salestype By ID
    //
    // Get Salestype By ID
    //
    //Future<SalesType> getSalestypeByID(String authorization, String xAPIKey, String name, { String xPin }) async 
    test('test getSalestypeByID', () async {
      // TODO
    });

    // Update Salestype By ID
    //
    // Update [object Object] By ID
    //
    //Future<SalesType> updateSalestypeByID(String authorization, String xAPIKey, String name, SalesType body, { String xPin }) async 
    test('test updateSalestypeByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.1.tar.gz: test/sales_type_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for SalesTypeApi
void main() {
  var instance = new SalesTypeApi();

  group('tests for SalesTypeApi', () {
    // Create Salestype
    //
    // Create Salestype
    //
    //Future<SalesType> createSalestype(String authorization, String xAPIKey, SalesType body, { String xPin }) async 
    test('test createSalestype', () async {
      // TODO
    });

    // Delete Salestype By ID
    //
    // Delete Salestype By ID
    //
    //Future deleteSalestypeByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test deleteSalestypeByID', () async {
      // TODO
    });

    // Get Salestype List
    //
    // Get Salestype  List
    //
    //Future<List<SalesType>> findSalestype(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findSalestype', () async {
      // TODO
    });

    // Get Salestype By ID
    //
    // Get Salestype By ID
    //
    //Future<SalesType> getSalestypeByID(String authorization, String xAPIKey, String id, { String xPin }) async 
    test('test getSalestypeByID', () async {
      // TODO
    });

    // Update Salestype By ID
    //
    // Update [object Object] By ID
    //
    //Future<SalesType> updateSalestypeByID(String authorization, String xAPIKey, String id, SalesType body, { String xPin }) async 
    test('test updateSalestypeByID', () async {
      // TODO
    });

  });
}
